@@ -66,12 +66,16 @@ def action_analyze(sources,
                    print_opts=False,
                    verbose=False,
                    extra=False,
-                   raw=False):
+                   raw=False,
+                   individuals=False,
+                   format=""):
     """
     Load up a model into ontospy and analyze it
     """
+    printDebug("Parsing ...", fg='white')
     for x in sources:
-        click.secho("Parsing %s..." % str(x), fg='white')
+        printInfo("# %s" % str(x), fg='white')
+    printInfo("")
 
     if extra:
         hide_base_schemas = False
@@ -82,33 +86,51 @@ def action_analyze(sources,
         hide_implicit_types = True
         hide_implicit_preds = True
 
+    if individuals:
+        hide_individuals = False
+    else:
+        hide_individuals = True
+
     if raw:
-        o = Ontospy(uri_or_path=sources, verbose=verbose, build_all=False)
+        o = Ontospy(
+            uri_or_path=sources, 
+            verbose=verbose, 
+            rdf_format=format, 
+            build_all=False)
         s = o.serialize()
-        print(s)
+        printInfo(s)
         return
     elif endpoint:
         g = Ontospy(
+            rdf_format=format, 
             sparql_endpoint=sources[0],
             verbose=verbose,
             hide_base_schemas=hide_base_schemas,
             hide_implicit_types=hide_implicit_types,
-            hide_implicit_preds=hide_implicit_preds)
+            hide_implicit_preds=hide_implicit_preds,
+            hide_individuals=hide_individuals)
         printDebug("Extracting classes info")
         g.build_classes()
         printDebug("..done")
         printDebug("Extracting properties info")
         g.build_properties()
         printDebug("..done")
+        if not hide_individuals:
+            printDebug("Extracting individuals info (WARNING - on Sparql endpoints this could lead to very long performance times")
+            g.build_individuals()
+            printDebug("..done")
     else:
         g = Ontospy(
             uri_or_path=sources,
+            rdf_format=format, 
             verbose=verbose,
             hide_base_schemas=hide_base_schemas,
             hide_implicit_types=hide_implicit_types,
-            hide_implicit_preds=hide_implicit_preds)
+            hide_implicit_preds=hide_implicit_preds,
+            hide_individuals=hide_individuals)
 
-    shellPrintOverview(g, print_opts)
+    if len(g.rdflib_graph):
+        shellPrintOverview(g, print_opts)
 
 
 def action_reveal_library():
@@ -129,7 +151,7 @@ def action_serialize(source, out_fmt="turtle", verbose=False):
 
     o = Ontospy(uri_or_path=source, verbose=verbose, build_all=False)
     s = o.serialize(out_fmt)
-    print(s)
+    printInfo(s)
 
 
 def action_jsonld_playground(source_path, verbose=False):
@@ -194,7 +216,6 @@ def action_listlocal(all_details=True):
 
 def _print2cols_ontologies():
     ontologies = get_localontologies()
-    ONTOSPY_LOCAL_MODELS = get_home_location()
 
     if ontologies:
         printDebug("------------", "tip")
@@ -216,7 +237,7 @@ def _print_table_ontologies():
     ONTOSPY_LOCAL_MODELS = get_home_location()
 
     if ontologies:
-        print("")
+        printDebug("")
         temp = []
         from collections import namedtuple
         Row = namedtuple('Row', ['N', 'Added', 'File'])
@@ -236,7 +257,7 @@ def _print_table_ontologies():
             # cached = str(os.path.exists(ONTOSPY_LOCAL_CACHE + "/" + file + ".pickle"))
             temp += [Row(_counter, last_modified_date, name)]
         pprinttable(temp)
-        print("")
+        printDebug("")
     return
 
 
@@ -255,11 +276,10 @@ def action_import(location, verbose=True):
         if location.startswith("www."):  #support for lazy people
             location = "http://%s" % str(location)
         if location.startswith("http"):
-            # print("here")
             headers = {'Accept': "application/rdf+xml"}
             try:
                 # Py2
-                req = urllib2.request(location, headers=headers)
+                req = urllib2.Request(location, headers=headers)
                 res = urllib2.urlopen(req)
             except:
                 # Py3
@@ -287,7 +307,6 @@ def action_import(location, verbose=True):
                 shutil.copy(location, fullpath)
             else:
                 raise ValueError('The location specified is not a file.')
-        # print("Saved local copy")
     except:
         printDebug(
             "Error retrieving file. Please make sure <%s> is a valid location."
@@ -327,8 +346,7 @@ def action_import_folder(location):
         for file in onlyfiles:
             if not file.startswith("."):
                 filepath = os.path.join(location, file)
-                # print(Fore.RED + "\n---------\n" + filepath + "\n---------" + Style.RESET_ALL)
-                click.secho(
+                printDebug(
                     "\n---------\n" + filepath + "\n---------", fg='red')
                 return action_import(filepath)
     else:
@@ -403,10 +421,11 @@ def _import_LOV(
         for x in options:
             uri, title, ns = x['uri'], x['titles'][0]['value'], x['nsp']
             # print("%s ==> %s" % (d['titles'][0]['value'], d['uri']))
-            click.echo(
+            printDebug(
                 click.style("[%d]" % counter, fg='blue') +
                 click.style(uri + " ==> ", fg='black') +
-                click.style(title, fg='red'))
+                click.style(title, fg='red'), 
+                err=True)
 
             counter += 1
 
@@ -420,7 +439,7 @@ def _import_LOV(
                 try:
                     _id = int(var)
                     ontouri = options[_id - 1]['uri']
-                    print(Fore.RED + "\n---------\n" + ontouri +
+                    printDebug(Fore.RED + "\n---------\n" + ontouri +
                           "\n---------" + Style.RESET_ALL)
                     action_analyze([ontouri])
                     if click.confirm(
@@ -429,7 +448,7 @@ def _import_LOV(
                         action_import(ontouri)
                     return
                 except:
-                    print("Error retrieving file. Import failed.")
+                    printDebug("Error retrieving file. Import failed.")
                     continue
 
 
@@ -457,10 +476,10 @@ def _import_PREFIXCC(keyword=""):
 
     counter = 1
     for x in options:
-        print(Fore.BLUE + Style.BRIGHT + "[%d]" % counter,
-              Style.RESET_ALL + x[0] + " ==> ", Fore.RED + x[1],
+        printDebug(Fore.BLUE + Style.BRIGHT + "[%d]" % counter +
+              Style.RESET_ALL + x[0] + " ==> " + Fore.RED + x[1] + 
               Style.RESET_ALL)
-        # print(Fore.BLUE + x[0], " ==> ", x[1])
+        # printDebug(Fore.BLUE + x[0] + " ==> " + x[1])
         counter += 1
 
     while True:
@@ -472,7 +491,7 @@ def _import_PREFIXCC(keyword=""):
             try:
                 _id = int(var)
                 ontouri = options[_id - 1][1]
-                print(Fore.RED + "\n---------\n" + ontouri + "\n---------" +
+                printDebug(Fore.RED + "\n---------\n" + ontouri + "\n---------" +
                       Style.RESET_ALL)
                 action_analyze([ontouri])
                 if click.confirm(
@@ -480,7 +499,7 @@ def _import_PREFIXCC(keyword=""):
                     action_import(ontouri)
                 return
             except:
-                print("Error retrieving file. Import failed.")
+                printDebug("Error retrieving file. Import failed.")
                 continue
 
 
@@ -491,7 +510,7 @@ def action_bootstrap(verbose=False):
     count = 0
     for s in BOOTSTRAP_ONTOLOGIES:
         count += 1
-        print(count, "<%s>" % s)
+        printInfo(count, "<%s>" % s)
 
     printDebug("--------------")
     printDebug("Note: this operation may take several minutes.")
@@ -563,30 +582,30 @@ def action_cache_reset():
     var = input(Style.BRIGHT + "=====\nProceed? (y/n) " + Style.RESET_ALL)
     if var == "y":
         repo_contents = get_localontologies()
-        print(Style.BRIGHT +
+        printInfo(Style.BRIGHT +
               "\n=====\n%d ontologies available in the local library\n=====" %
               len(repo_contents) + Style.RESET_ALL)
         for onto in repo_contents:
             fullpath = ONTOSPY_LOCAL_MODELS + "/" + onto
             try:
-                print(Fore.RED + "\n=====\n" + onto + Style.RESET_ALL)
-                print("Loading graph...")
+                printInfo(Fore.RED + "\n=====\n" + onto + Style.RESET_ALL)
+                printInfo("Loading graph...")
                 g = Ontospy(fullpath)
-                print("Loaded ", fullpath)
+                printInfo("Loaded ", fullpath)
             except:
                 g = None
-                print(
+                printDebug(
                     "Error parsing file. Please make sure %s contains valid RDF."
                     % fullpath)
 
             if g:
-                print("Caching...")
+                printInfo("Caching...")
                 do_pickle_ontology(onto, g)
 
-        print(Style.BRIGHT + "===Completed===" + Style.RESET_ALL)
+        printDebug(Style.BRIGHT + "===Completed===" + Style.RESET_ALL)
 
     else:
-        print("Goodbye")
+        printDebug("Goodbye")
 
 
 def actions_delete():
@@ -636,6 +655,10 @@ def action_visualize(args,
                      title="",
                      viztype="",
                      theme="",
+                     preflabel="",
+                     preflang="",
+                     extra= False,
+                     individuals= False,
                      verbose=False):
     """
     export model into another format eg html, d3 etc...
@@ -651,6 +674,20 @@ def action_visualize(args,
         ontouri = args[0]
         islocal = False
 
+    if extra:
+        hide_base_schemas = False
+        hide_implicit_types = False
+        hide_implicit_preds = False
+    else:
+        hide_base_schemas = True
+        hide_implicit_types = True
+        hide_implicit_preds = True
+
+    if individuals:
+        hide_individuals = False
+    else:
+        hide_individuals = True
+
     # select a visualization
     if viztype:
         viztype = select_visualization(viztype)
@@ -663,9 +700,18 @@ def action_visualize(args,
     # 2017-01-23: bypass pickled stuff as it has wrong counts etc..
     # get ontospy graph
     printDebug("Loading graph...", dim=True)
-    g = Ontospy(ontouri, verbose=verbose)
 
-    # put in home folder by default: <ontouri>/<viztype>/files..
+    g = Ontospy(
+        ontouri, 
+        verbose=verbose, 
+        pref_title=preflabel, 
+        pref_lang=preflang,
+        hide_base_schemas=hide_base_schemas,
+        hide_implicit_types=hide_implicit_types,
+        hide_implicit_preds=hide_implicit_preds,
+        hide_individuals=hide_individuals)
+
+    # put viz in home folder by default: <ontouri>/<viztype>/files..
     if not path:
         from os.path import expanduser
         home = expanduser("~")
