@@ -105,18 +105,39 @@ def remove_duplicates(seq, idfun=None):
     return result
 
 
-def printDebug(text, mystyle="", **kwargs):
-    """
-    util for printing in colors using click.secho()
+def printDebug(text, mystyle="", err=True, **kwargs):
+    """Wrapper around click.secho() for printing in colors with various defaults.
 
     :kwargs = you can do printDebug("s", bold=True)
 
-    2018-12-06: by default print to standard error (err=True)
+    2018-12-06: by default print to standard error stderr (err=True)
+    https://click.palletsprojects.com/en/5.x/api/#click.echo
+    This means that the output is ok with `less` and when piped to other commands (or files)
 
     Styling output:
     <http://click.pocoo.org/5/api/#click.style>
     Styles a text with ANSI styles and returns the new string. By default the styling is self contained which means that at the end of the string a reset code is issued. This can be prevented by passing reset=False.
 
+    This works also with inner click styles eg
+
+    ```python
+    uri, title = "http://example.com", "My ontology"
+    printDebug(click.style("[%d]" % 1, fg='blue') +
+               click.style(uri + " ==> ", fg='black') +
+               click.style(title, fg='red'))
+    ```
+
+    Or even with Colorama
+
+    ```
+    from colorama import Fore, Style
+
+    printDebug(Fore.BLUE + Style.BRIGHT + "[%d]" % 1 + 
+            Style.RESET_ALL + uri + " ==> " + Fore.RED + title + 
+            Style.RESET_ALL)
+    ```
+
+
     Examples:
 
     click.echo(click.style('Hello World!', fg='green'))
@@ -149,47 +170,30 @@ def printDebug(text, mystyle="", **kwargs):
     """
 
     if mystyle == "comment":
-        click.secho(text, dim=True, err=True)
+        click.secho(text, dim=True, err=err)
     elif mystyle == "important":
-        click.secho(text, bold=True, err=True)
+        click.secho(text, bold=True, err=err)
     elif mystyle == "normal":
-        click.secho(text, reset=True, err=True)
+        click.secho(text, reset=True, err=err)
     elif mystyle == "red" or mystyle == "error":
-        click.secho(text, fg='red', err=True)
+        click.secho(text, fg='red', err=err)
     elif mystyle == "green":
-        click.secho(text, fg='green', err=True)
+        click.secho(text, fg='green', err=err)
     else:
-        click.secho(text, **kwargs)
+        click.secho(text, err=err, **kwargs)
 
 
-def printComment(text, mystyle="comment", **kwargs):
-    """
-    wrapper around click.secho()
-    .. same as printDebug, but just one option
-    [for backward compatibility]
+
+
+def printInfo(text, mystyle="", **kwargs):
+    """Wrapper around printDebug for printing ALWAYS to stdout
+    This means that the output can be grepped etc..
+    NOTE this output will be picked up by pipes etc..
+
+    Fixes https://github.com/lambdamusic/Ontospy/issues/76
     """
+    printDebug(text, mystyle, False, **kwargs)
 
-    click.secho(text, fg='green', **kwargs)
-
-
-def OLD_printDebug(s, style=None):
-    """
-    util for printing in colors to sys.stderr stream
-    """
-    if style == "comment":
-        s = Style.DIM + s + Style.RESET_ALL
-    elif style == "important":
-        s = Style.BRIGHT + s + Style.RESET_ALL
-    elif style == "normal":
-        s = Style.RESET_ALL + s + Style.RESET_ALL
-    elif style == "red":
-        s = Fore.RED + s + Style.RESET_ALL
-    elif style == "green":
-        s = Fore.GREEN + s + Style.RESET_ALL
-    try:
-        print(s, file=sys.stderr)
-    except:
-        pass
 
 
 def pprint2columns(llist, max_length=60):
@@ -210,13 +214,13 @@ def pprint2columns(llist, max_length=60):
 
     if col_width > max_length:
         for el in llist:
-            print(el)
+            printInfo(el)
     else:
         column1 = llist[:int(len(llist) / 2)]
         column2 = llist[int(len(llist) / 2):]
         for c1, c2 in zip(column1, column2):
             space = " " * (col_width - len(c1))
-            print("%s%s%s" % (c1, space, c2))
+            printInfo("%s%s%s" % (c1, space, c2))
 
 
 def pprinttable(rows):
@@ -261,15 +265,15 @@ def pprinttable(rows):
         pattern = " | ".join(formats)
         hpattern = " | ".join(hformats)
         separator = "-+-".join(['-' * n for n in lens])
-        print(hpattern % tuple(headers))
-        print(separator)
+        printInfo(hpattern % tuple(headers))
+        printInfo(separator)
         for line in rows:
-            print(pattern % tuple(line))
+            printInfo(pattern % tuple(line))
     elif len(rows) == 1:
         row = rows[0]
         hwidth = len(max(row._fields, key=lambda x: len(x)))
         for i in range(len(row)):
-            print("%*s = %s" % (hwidth, row._fields[i], row[i]))
+            printInfo("%*s = %s" % (hwidth, row._fields[i], row[i]))
 
 
 def save_anonymous_gist(title, files):
@@ -295,7 +299,7 @@ def save_anonymous_gist(title, files):
     try:
         from github3 import create_gist
     except:
-        print("github3 library not found (pip install github3)")
+        printDebug("github3 library not found (pip install github3)")
         raise SystemExit(1)
 
     gist = create_gist(title, files)
@@ -391,23 +395,23 @@ def printBasicInfo(onto):
     """
     rdfGraph = onto.rdflib_graph
 
-    print("_" * 50, "\n")
-    print("TRIPLES = %s" % len(rdfGraph))
-    print("_" * 50)
-    print("\nNAMESPACES:\n")
+    printInfo("_" * 50, "\n")
+    printInfo("TRIPLES = %s" % len(rdfGraph))
+    printInfo("_" * 50)
+    printInfo("\nNAMESPACES:\n")
     for x in onto.ontologyNamespaces:
-        print("%s : %s" % (x[0], x[1]))
+        printInfo("%s : %s" % (x[0], x[1]))
 
-    print("_" * 50, "\n")
-    print("ONTOLOGY METADATA:\n")
+    printInfo("_" * 50, "\n")
+    printInfo("ONTOLOGY METADATA:\n")
     for x, y in onto.ontologyAnnotations():
-        print("%s: \n	 %s" % (uri2niceString(x, onto.ontologyNamespaces),
+        printInfo("%s: \n	 %s" % (uri2niceString(x, onto.ontologyNamespaces),
                               uri2niceString(y, onto.ontologyNamespaces)))
-    print("_" * 50, "\n")
+    printInfo("_" * 50, "\n")
 
-    print("CLASS TAXONOMY:\n")
+    printInfo("CLASS TAXONOMY:\n")
     onto.printClassTree()
-    print("_" * 50, "\n")
+    printInfo("_" * 50, "\n")
 
 
 def inferMainPropertyType(uriref):
@@ -492,7 +496,7 @@ def printGenericTree(element,
     else:
         bestLabel = ""
 
-    printDebug("%s%s%s%s" % (_id_, "-" * 4 * level, element.qname, bestLabel))
+    printInfo("%s%s%s%s" % (_id_, "-" * 4 * level, element.qname, bestLabel))
 
     # recursion
     for sub in element.children():
@@ -607,7 +611,7 @@ def sort_uri_list_by_name(uri_list, bypassNamespace=False):
             return sorted(uri_list)
     except:
         # TODO: do more testing.. maybe use a unicode-safe method instead of __str__
-        print(
+        printDebug(
             "Error in <sort_uri_list_by_name>: possibly a UnicodeEncodeError")
         return uri_list
 
@@ -818,49 +822,64 @@ def shellPrintOverview(g, opts={'labels': False}):
         labels = opts['labels']
     except:
         labels = False
+    try:
+        individuals = opts['individuals']
+    except:
+        individuals = False
 
-    print(Style.BRIGHT + "Namespaces\n-----------" + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "Namespaces\n-----------" + Style.RESET_ALL)
     if g.namespaces:
         for p, u in g.namespaces:
             row = Fore.GREEN + "%s" % p + Fore.BLACK + "  %s" % u + Fore.RESET
-            print(row)
+            printInfo(row)
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
 
-    print(Style.BRIGHT + "\nOntologies\n-----------" + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "\nOntologies\n-----------" + Style.RESET_ALL)
     if ontologies:
         for o in ontologies:
             o.printTriples()
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
 
-    print(Style.BRIGHT + "\nClasses\n" + "-" * 10 + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "\nClasses\n" + "-" * 10 + Style.RESET_ALL)
     if g.all_classes:
         g.printClassTree(showids=False, labels=labels)
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
 
-    print(Style.BRIGHT + "\nProperties\n" + "-" * 10 + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "\nProperties\n" + "-" * 10 + Style.RESET_ALL)
     if g.all_properties:
         g.printPropertyTree(showids=False, labels=labels)
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
 
-    print(Style.BRIGHT + "\nSKOS Concepts\n" + "-" * 10 + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "\nSKOS Concepts\n" + "-" * 10 + Style.RESET_ALL)
     if g.all_skos_concepts:
 
         g.printSkosTree(showids=False, labels=labels)
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
 
-    print(Style.BRIGHT + "\nSHACL Shapes\n" + "-" * 10 + Style.RESET_ALL)
+    printInfo(Style.BRIGHT + "\nSHACL Shapes\n" + "-" * 10 + Style.RESET_ALL)
     if g.all_shapes:
 
         for x in g.all_shapes:
-            printDebug("%s" % (x.qname))
+            printInfo("%s" % (x.qname))
             # printDebug("%s" % (x.bestLabel()), "comment")
     else:
-        printDebug("None found", "comment")
+        printInfo("None found", "comment")
+    
+    if individuals:
+        printInfo(Style.BRIGHT + "\nIndividuals\n" + "-" * 10 + Style.RESET_ALL)
+        if g.all_individuals:
+
+            for x in g.all_individuals:
+                printInfo("%s" % (x.qname))
+                # printDebug("%s" % (x.bestLabel()), "comment")
+        else:
+            printInfo("None found", "comment")
+
 
 
 def slugify(value):
@@ -877,13 +896,13 @@ def slugify(value):
 
 
 def get_files_with_extensions(folder, extensions):
-    """walk dir and return .* files as a list
+    """walk dir and return .* files as a list. Hidden files are ignored.
     Note: directories are walked recursively"""
     out = []
     for root, dirs, files in os.walk(folder):
         for file in files:
             filename, file_extension = os.path.splitext(file)
-            if file_extension.replace(".", "") in extensions:
+            if not filename.startswith('.') and file_extension.replace(".", "") in extensions:
                 out += [os.path.join(root, file)]
                 # break
 
